@@ -5,11 +5,11 @@ use warnings;
 use parent qw(Mojo::Base);
 
 use File::Spec ();
-use Mojo::Command;
+use Mojo::Loader;
 use Text::Xslate ();
 use Try::Tiny;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->attr('xslate');
@@ -29,7 +29,7 @@ sub _init {
 
     if ($app) {
         $cache_dir = $app->home->rel_dir('tmp/compiled_templates');
-        push @path, Mojo::Command->new->get_all_data(
+        push @path, Mojo::Loader->new->data(
             $app->renderer->classes->[0],
         );
     }
